==> kubernetes-model-flowcontrol-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/FlowSchemaFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FlowSchemaFluent<A extends FlowSchemaFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public FlowSchemaFluent.MetadataNested<A> withNewMetadata();
  public FlowSchemaFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public FlowSchemaFluent.MetadataNested<A> editMetadata();
  public FlowSchemaFluent.MetadataNested<A> editOrNewMetadata();
  public FlowSchemaFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowSchemaSpec getSpec();
  public FlowSchemaSpec buildSpec();
  public A withSpec(FlowSchemaSpec spec);
  public Boolean hasSpec();
  public FlowSchemaFluent.SpecNested<A> withNewSpec();
  public FlowSchemaFluent.SpecNested<A> withNewSpecLike(FlowSchemaSpec item);
  public FlowSchemaFluent.SpecNested<A> editSpec();
  public FlowSchemaFluent.SpecNested<A> editOrNewSpec();
  public FlowSchemaFluent.SpecNested<A> editOrNewSpecLike(FlowSchemaSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowSchemaStatus getStatus();
  public FlowSchemaStatus buildStatus();
  public A withStatus(FlowSchemaStatus status);
  public Boolean hasStatus();
  public FlowSchemaFluent.StatusNested<A> withNewStatus();
  public FlowSchemaFluent.StatusNested<A> withNewStatusLike(FlowSchemaStatus item);
  public FlowSchemaFluent.StatusNested<A> editStatus();
  public FlowSchemaFluent.StatusNested<A> editOrNewStatus();
  public FlowSchemaFluent.StatusNested<A> editOrNewStatusLike(FlowSchemaStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<FlowSchemaFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,FlowSchemaSpecFluent<FlowSchemaFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,FlowSchemaStatusFluent<FlowSchemaFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1alpha1/FlowSchemaFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FlowSchemaFluent<A extends FlowSchemaFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public FlowSchemaFluent.MetadataNested<A> withNewMetadata();
  public FlowSchemaFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public FlowSchemaFluent.MetadataNested<A> editMetadata();
  public FlowSchemaFluent.MetadataNested<A> editOrNewMetadata();
  public FlowSchemaFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowSchemaSpec getSpec();
  public FlowSchemaSpec buildSpec();
  public A withSpec(FlowSchemaSpec spec);
  public Boolean hasSpec();
  public FlowSchemaFluent.SpecNested<A> withNewSpec();
  public FlowSchemaFluent.SpecNested<A> withNewSpecLike(FlowSchemaSpec item);
  public FlowSchemaFluent.SpecNested<A> editSpec();
  public FlowSchemaFluent.SpecNested<A> editOrNewSpec();
  public FlowSchemaFluent.SpecNested<A> editOrNewSpecLike(FlowSchemaSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowSchemaStatus getStatus();
  public FlowSchemaStatus buildStatus();
  public A withStatus(FlowSchemaStatus status);
  public Boolean hasStatus();
  public FlowSchemaFluent.StatusNested<A> withNewStatus();
  public FlowSchemaFluent.StatusNested<A> withNewStatusLike(FlowSchemaStatus item);
  public FlowSchemaFluent.StatusNested<A> editStatus();
  public FlowSchemaFluent.StatusNested<A> editOrNewStatus();
  public FlowSchemaFluent.StatusNested<A> editOrNewStatusLike(FlowSchemaStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<FlowSchemaFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,FlowSchemaSpecFluent<FlowSchemaFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,FlowSchemaStatusFluent<FlowSchemaFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
